Quade: The Friendly QA App
==========================

Quade is a Django app that makes quality assurance testing easier.
It handles the burden of repeatedly setting up the same data,
and helps you track the progress of your tests.

Dive in with our :doc:`quickstart`!

.. toctree::
   :maxdepth: 2
   :hidden:
   
   quickstart
   installation
   models
   settings
   celery
